==> deepin-screen-recorder_5.8.1.orig.tar.xz: deepin-screen-recorder-5.8.1/translations/deepin-screen-recorder_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Ekran kaydını durdurmak için 
tepsi simgesine tıklayın ya da kısayola yeniden basın</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Kayıt</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekran Görüntüsü</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Ekran Alıntısı</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Kayıt başarısız. Lütfen ana dizine kaydedin.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Ekran görüntüsü tamamlandı</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>alan seç</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Şuraya kaydedildi %1</translation>
    </message>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Ekran Alıntısı %1 saniye içinde başlayacak</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Yoksay</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Pano</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Ekran kayıt dosyası kaydediliyor, lütfen bekleyin...</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Geri al</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>Screen Capture</source>
        <translation>Ekran Görüntüsü</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Kayıt tamamlandı</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Şuraya kaydedildi %1</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Ekran Alıntısı %1 saniye içinde başlayacak</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Metni buraya gir</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Başlat/Ekran Görüntüsü</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Çıkış/Kaydet</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Çizim</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Boyut Ayarı</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Hızlı başlat</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Pencere ekran görüntüsü</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Gecikmeli ekran görüntüsü</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Tam ekran görüntüsü</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Panoya kopyala</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Dikdörtgen</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elips</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Çizgi</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Kalem</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Metin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Geri al</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Yüksekliği artır</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Yüksekliği azalt</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Sol genişliği artır</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Sağ genişliği artır</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Yüksekliği artır</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Yüksekliği azalt</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Sol genişliği azalt</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Sağ genişliği azalt</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Kısayolları görüntüle</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Bulanık</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mozaik</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Ses Aç</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Sistem Sesi</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Ses Kapat</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Tuş Vuruşunu Göster</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Tuş Vuruşunu Gizle</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webcam Açık</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webcam Kapalı</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Tıklamayı Göster</translation>
    </message>
    <message>
        <source>Hide Click</source>
        <translation>Tıklamayı Gizle</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Biçim:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Dikdörtgen</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elips</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Çizgi</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>ok</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Kalem</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Metin</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Şuraya kaydet</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Masaüstü</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Resimler</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Klasör</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Biçim</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Pano</translation>
    </message>
    <message>
        <source>Edit in Draw</source>
        <translation>Çizim ile düzelt</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>İşaretçiyi göster</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Kayıtlar</translation>
    </message>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Ekran kaydı şu anda desteklenmiyor</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder_5.9.3.orig.tar.xz: deepin-screen-recorder-5.9.3/translations/deepin-screen-recorder_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Ekran kaydını durdurmak için 
tepsi simgesine tıklayın ya da kısayola yeniden basın</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Kayıt</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekran Görüntüsü</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Ekran Alıntısı</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Kayıt başarısız. Lütfen ana dizine kaydedin.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Ekran görüntüsü tamamlandı</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>alan seç</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Şuraya kaydedildi %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Yoksay</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Pano</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Ekran kayıt dosyası kaydediliyor, lütfen bekleyin...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>İşlem sırasında pencere efekti devre dışı bırakıldığı için, kayıt durdurulmalıdır.</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekran Görüntüsü</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Geri al</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Kayıt tamamlandı</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Şuraya kaydedildi %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Kayıt</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Ekran Alıntısı %1 saniye içinde başlayacak</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Metni buraya gir</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Başlat/Ekran Görüntüsü</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Çıkış/Kaydet</translation>
    </message>
    <message>
        <source>Drawing</source>
        <translation>Çizim</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Boyut Ayarı</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Hızlı başlat</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Pencere ekran görüntüsü</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Gecikmeli ekran görüntüsü</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Tam ekran görüntüsü</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Dikdörtgen</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elips</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Çizgi</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Kalem</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Metin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Geri al</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Yüksekliği artır</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Yüksekliği azalt</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Sol genişliği artır</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Sağ genişliği artır</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Yüksekliği artır</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Yüksekliği azalt</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Sol genişliği azalt</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Sağ genişliği azalt</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Kısayolları görüntüle</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Ses</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Vuruş</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Ekran kaydını başlat</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Kaydı/Başlat</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Fare</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation>Bulanık</translation>
    </message>
    <message>
        <source>Mosaic</source>
        <translation>Mozaik</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation>Ses Aç</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System Audio</source>
        <translation>Sistem Sesi</translation>
    </message>
    <message>
        <source>Sound Off</source>
        <translation>Ses Kapat</translation>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation>Tuş Vuruşunu Göster</translation>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation>Tuş Vuruşunu Gizle</translation>
    </message>
    <message>
        <source>Webcam On</source>
        <translation>Webcam Açık</translation>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation>Webcam Kapalı</translation>
    </message>
    <message>
        <source>Show Click</source>
        <translation>Tıklamayı Göster</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Biçim:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Dikdörtgen</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elips</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Çizgi</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>ok</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Kalem</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Metin</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Şuraya kaydet</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Masaüstü</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Resimler</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Klasör</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Biçim</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Pano</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>İşaretçiyi göster</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Fare</translation>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation>İşaretçiyi Göster</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>Daha iyi video efekti elde etmek için kayıt alanını %1*%2 içinde ayarlayın</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Recordings</source>
        <translation>Kayıtlar</translation>
    </message>
</context>
</TS>
